Index: trunk/info/info/alkisn/alkisinlayausk.php
===================================================================
--- trunk/info/info/alkisn/alkisinlayausk.php	(revision 394)
+++ trunk/info/info/alkisn/alkisinlayausk.php	(revision 398)
@@ -15,4 +15,5 @@
 	2017-06-08 Validierung Eingabeparameter, Feinkorrekturen
 	2017-10-09 Sauber filtern auf endet IS NULL
+	2017-12-20 Fehlerkorrektur: Link StraÃe ohne gml_id, Bessere Title fÃŒr Links, Icon an Lage.
 */
 session_start();
@@ -125,5 +126,5 @@
 pg_free_result($res);
 
-// Lage MIT HausNr (Adresse)
+// Lage  M I T  HausNr (Adresse)
 $sql ="SELECT DISTINCT s.gml_id AS kgml, l.gml_id, s.bezeichnung, l.hausnummer 
 FROM ax_flurstueck f JOIN ax_lagebezeichnungmithausnummer l ON l.gml_id=ANY(f.weistauf)
@@ -142,15 +143,26 @@
 $kgmlalt='';
 while($row = pg_fetch_array($res)) {
-	$sname = htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8"); // Str.-Name
-	echo "\n<tr>\n\t\n\t<td class='lr'>".$sname."&nbsp;".$row["hausnummer"]."</td>"
-	."\n\t<td>\n\t\t<p class='nwlink noprint'>";
+	$sname=htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8"); // Str.-Name
+	if (substr($sname, strlen($sname) -3, 3) == 'weg') { // Versuch fuer korrekten Satzbau
+		$slink=" am ".$sname;
+	} else {
+		$slink=" an der ".$sname;
+	}
+	$hsnr=$row["hausnummer"];
+
+	// linke Spalte
+	echo "\n<tr>\n\t\n\t<td class='lr'><img src='ico/Lage_mit_Haus.png' width='16' height='16' alt='MIT'>&nbsp;".$sname."&nbsp;".$hsnr."</td>";
+
+	// rechte Spalte
+	echo "\n\t<td>\n\t\t<p class='nwlink noprint'>";
 	$kgml=$row["kgml"]; // Wiederholung vermeiden
+
 	if ($kgml != $kgmlalt) { // NEUE Strasse vor Lage
 		$kgmlalt=$kgml; // Katalog GML-ID
-		echo "\n\t\t\t<a title='Flurst&uuml;cke an der Stra&szlig;e' "
-		."href='javascript:imFenster(\"alkisstrasse.php?gkz=".$gkz."&amp;gmlid=".$row["kgml"]."\")'>Stra&szlig;e "
+		echo "\n\t\t\t<a title='Flurst&uuml;cke mit oder ohne Hausnummer".$slink."' "
+		."href='javascript:imFenster(\"alkisstrasse.php?gkz=".$gkz."&amp;gmlid=".$kgml."\")'>Stra&szlig;e "
 		."<img src='ico/Strassen.png' width='16' height='16' alt='STRA'></a>";
 	}
-		echo "\n\t\t\t<a title='Lagebezeichnung mit Hausnummer' "
+	echo "\n\t\t\t<a title='Flurst&uuml;cke und Geb&auml;ude mit Hausnummer ".$hsnr."' "
 		."href='javascript:imFenster(\"alkislage.php?gkz=".$gkz."&amp;ltyp=m&amp;gmlid=".$row["gml_id"]."\")'>Lage "
 		."<img src='ico/Lage_mit_Haus.png' width='16' height='16' alt='HAUS'></a>&nbsp;"
@@ -159,44 +171,64 @@
 }
 pg_free_result($res);
-if ($j == 0) { // keine HsNr gefunden
-	// Lage OHNE HausNr
-	$sql="SELECT DISTINCT s.gml_id AS kgml, l.gml_id, s.bezeichnung, l.unverschluesselt "
+
+// Lage  O H N E   HausNr
+$sql="SELECT DISTINCT s.gml_id AS kgml, l.gml_id, s.bezeichnung, l.unverschluesselt "
 	."FROM ax_flurstueck f JOIN ax_lagebezeichnungohnehausnummer l ON l.gml_id=ANY(f.zeigtauf) "
 	."LEFT JOIN ax_lagebezeichnungkatalogeintrag s ON l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND l.lage=s.lage "
 	."WHERE f.gml_id= $1 AND f.endet IS NULL AND l.endet IS NULL AND s.endet IS NULL ORDER BY s.bezeichnung;";
 
-	$v=array($gmlid);
-	$res=pg_prepare("", $sql);
-	$res=pg_execute("", $v);
-	if (!$res) {
-		echo "\n<p class='err'>Fehler bei Lagebezeichnung ohne Hausnummer.</p>";
-		if ($debug > 2) {echo "\n<p class='err'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
-	}
-	while($row = pg_fetch_array($res)) {
-		$sname =htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8"); // Str.-Name
-		$gewann=htmlentities($row["unverschluesselt"], ENT_QUOTES, "UTF-8");
-		echo "\n<tr>";
-		if ($sname != "") { // Typ=Strasse
-			echo "\n\t<td class='lr' title='An Stra&szlig;e aber ohne Hausnummer'>".$sname."&nbsp;</td>";
-			$ico="Lage_an_Strasse.png";
-		} else {
-			echo "\n\t<td class='lr' title='Gewanne'>".$gewann."&nbsp;</td>";
-			$ico="Lage_Gewanne.png";
-		}
-		echo "\n\t<td>\n\t\t<p class='nwlink noprint'>";
+$v=array($gmlid);
+$res=pg_prepare("", $sql);
+$res=pg_execute("", $v);
+if (!$res) {
+	echo "\n<p class='err'>Fehler bei Lagebezeichnung ohne Hausnummer.</p>";
+	if ($debug > 2) {echo "\n<p class='err'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
+}
+$kgmlalt='';
+while($row = pg_fetch_array($res)) {
+	$sname=htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8"); // Str.-Name
+
+	if (substr($sname, strlen($sname) -3, 3) == 'weg') { // Versuch fuer korrekten Satzbau
+		$slink=" am ".$sname;
+	} else {
+		$slink=" an der ".$sname;
+	}
+
+
+	$gewann=htmlentities($row["unverschluesselt"], ENT_QUOTES, "UTF-8");
+	echo "\n<tr>";
+
+	// linke Spalte
+	if ($sname != "") { // Typ=Strasse
+		$ico="Lage_an_Strasse.png";
+		echo "\n\t<td class='lr' title='An Stra&szlig;e aber ohne Hausnummer'><img src='ico/".$ico."' width='16' height='16' alt='OHNE'> ".$sname."&nbsp;</td>";
+	} else {
+		$ico="Lage_Gewanne.png";
+		echo "\n\t<td class='lr' title='Gewanne'><img src='ico/".$ico."' width='16' height='16' alt='Gewanne'> ".$gewann."&nbsp;</td>";
+	}
+
+	// rechte Spalte
+	echo "\n\t<td>\n\t\t<p class='nwlink noprint'>";
+	if ($sname != "") { // Typ=Strasse
 		$kgml=$row["kgml"]; // Wiederholung vermeiden
 		if ($kgml != $kgmlalt) { // NEUE Strasse vor Lage-O
 			$kgmlalt=$kgml; // Katalog GML-ID
-			echo "\n\t\t\t<a title='Flurst&uuml;cke an der Stra&szlig;e' "
-			."href='javascript:imFenster(\"alkisstrasse.php?gkz=".$gkz."&amp;gmlid=".$row["kgml"]."\")'>Stra&szlig;e "
+			echo "\n\t\t\t<a class='noprint' title='Flurst&uuml;cke mit oder ohne Hausnummer".$slink."' "
+			."href='javascript:imFenster(\"alkisstrasse.php?gkz=".$gkz."&amp;gmlid=".$kgml."\")'>Stra&szlig;e "
 			."<img src='ico/Strassen.png' width='16' height='16' alt='STRA'></a>";
 		}
-		echo "\n\t\t\t<a title='Lagebezeichnung ohne Hausnummer' "
+		echo "\n\t\t\t<a class='noprint' title='Flurst&uuml;cke ohne Hausnummer".$slink."' "
 		."href='javascript:imFenster(\"alkislage.php?gkz=".$gkz."&amp;ltyp=o&amp;gmlid=".$row["gml_id"]."\")'>Lage "
 		."<img src='ico/".$ico."' width='16' height='16' alt='OHNE'></a>&nbsp;"
 		."\n\t\t</p>\n\t</td>\n</tr>";
-	}
-	pg_free_result($res);
-}
+	} else { // Typ Gewanne
+		echo "\n\t\t\t<a title='Flurst&uuml;cke mit dieser Gewanne als Lagebezeichnung' "
+		."href='javascript:imFenster(\"alkislage.php?gkz=".$gkz."&amp;ltyp=o&amp;gmlid=".$row["gml_id"]."\")'>Gewanne "
+		."<img src='ico/".$ico."' width='16' height='16' alt='Gewanne'></a>&nbsp;"
+		."\n\t\t</p>\n\t</td>\n</tr>";
+	}
+}
+pg_free_result($res);
+
 echo "\n</table>";
 
@@ -205,5 +237,5 @@
 
 // *** G R U N D B U C H ***
-echo "\n<h2><img src='ico/Grundbuch_zu.png' width='16' height='16' alt=''> Grundbuch</h2>";
+echo "\n<h2><img src='ico/Grundbuch_zu.png' width='16' height='16' alt='GB'> Grundbuch</h2>";
 
 // FS >istgebucht> GS >istbestandteilvon> GB.
@@ -228,5 +260,5 @@
 while($rowg = pg_fetch_array($resg)) {
 	$beznam=$rowg["bezeichnung"];
-	echo "\n<hr>\n<table class='outer'>\n<tr>\n<td>";
+	echo "\n<table class='outer'>\n<tr>\n<td>";
 		$blattkey=$rowg["blattart"]; // Key
 		$blattart=$rowg["blattartv"]; // Value
Index: trunk/info/info/alkisn/alkisbestnw.php
===================================================================
--- trunk/info/info/alkisn/alkisbestnw.php	(revision 394)
+++ trunk/info/info/alkisn/alkisbestnw.php	(revision 398)
@@ -110,22 +110,29 @@
 
 // Vorab pruefen, ob der Fall "Rechte an .." vorliegt.
-if ($blattkey == 1000) { // GB-Blatt  <istBestandteilVon<  sh=herrschend  >an/zu>  sd=dienend
-	$sql="SELECT count(sd.laufendenummer) AS anzahl "
-	."FROM ax_buchungsstelle sh JOIN ax_buchungsstelle sd ON (sd.gml_id=ANY(sh.an) OR sd.gml_id=ANY(sh.zu)) "
-	."WHERE sh.istbestandteilvon= $1 AND sd.endet IS NULL AND sh.endet IS NULL;";
-
-	$v=array($gmlid); // GB-Blatt
-	$res=pg_prepare("", $sql);
-	$res=pg_execute("", $v);
-	if (!$res) echo "\n<p class='err'>Fehler bei Suche nach Buchungen.</p>";
-	$row=pg_fetch_array($res);
-	$anz=$row["anzahl"];
-} else { // 2000: Katasterblatt, 3000: Pseudoblatt, 5000: Fiktives Blatt
-	$anz=0;
-}
-if ($anz > 0) { // auch Rechte: dann erweiterter Tabellen-Kopf
-	echo "\n<hr>\n\n<h3><img src='ico/Flurstueck.png' width='16' height='16' alt=''> Rechte und Flurst&uuml;cke</h3>"
-	."\n<table class='fs'>"
-	."\n<tr>" // zus. Kopfz.
+// ToDo: +++ Es gibt auch den Fall, dass auf der nÃ€chsten Stufe "nur Rechte" angezeigt werden, noch keine FlurstÃŒcke
+// ++ Also 3 MÃ¶glichkeiten:
+// - Nur Rechte an  (+++ FEHLT NOCH ++)
+// - Rechte und FlurstÃŒcke
+// - FlurstÃŒcke
+// +++ Herrschend/Dienend per "title" auf den Ãberschriften ("Rechte" / "Berechtigte GrundbÃŒcher") erlÃ€utern
+
+// GB-Blatt  <istBestandteilVon<  sh=herrschend  >an/zu>  sd=dienend
+$sql="SELECT count(sd.laufendenummer) AS anzahl "
+."FROM ax_buchungsstelle sh JOIN ax_buchungsstelle sd ON (sd.gml_id=ANY(sh.an) OR sd.gml_id=ANY(sh.zu)) "
+."WHERE sh.istbestandteilvon= $1 AND sd.endet IS NULL AND sh.endet IS NULL;";
+
+$v=array($gmlid); // GB-Blatt
+$res=pg_prepare("", $sql);
+$res=pg_execute("", $v);
+if (!$res) echo "\n<p class='err'>Fehler bei Suche nach Buchungen.</p>";
+$row=pg_fetch_array($res);
+$anz=$row["anzahl"];
+
+echo "\n<hr>\n\n<h3><img src='ico/Flurstueck.png' width='16' height='16' alt=''>";
+if ($anz > 0) { // auch "Rechte an"
+	echo " Rechte und Flurst&uuml;cke</h3>\n<table class='fs'>";
+
+	// zusaetzliche Kopfzeile "Rechte"
+	echo "\n<tr>" 
 		."\n\t<td>&nbsp;</td>"
 		."\n\t<td class='dien' title='herrschendes Grundst&uuml;ck'>herrschende Buchungsart</td>"
@@ -137,8 +144,9 @@
 		."\n\t<td>&nbsp;</td>"
 	."\n</tr>";
-} else { // nur FlurstÃŒcke, keine Rechte an/zu anderen Buchungen
-	echo "\n<hr>\n\n<h3><img src='ico/Flurstueck.png' width='16' height='16' alt=''> Flurst&uuml;cke</h3>"
-	."\n<table class='fs'>";
-} // gemeinsame Kopfzeile
+} else { // keine Rechte an .., nur FlurstÃŒcke gebucht
+	echo " Flurst&uuml;cke</h3>\n<table class='fs'>";
+}
+
+// gemeinsame Kopfzeile "Buchung + FlurstÃŒck"
 echo "\n<tr>"
 	."\n\t<td class='heads' title='laufende Nummer Bestandsverzeichnis (BVNR) = Grundst&uuml;ck'><span class='wichtig'>BVNR</span><img src='ico/sort.png' width='10' height='10' alt='' title='prim&auml;re Sortierung'></td>"
Index: trunk/info/info/alkisn/alkisauszug.css
===================================================================
--- trunk/info/info/alkisn/alkisauszug.css	(revision 394)
+++ trunk/info/info/alkisn/alkisauszug.css	(revision 398)
@@ -19,4 +19,5 @@
 	2017-10-11	BodenschÃ€tzung
 	2017-10-17	td.nwlink min-width
+	2017-12-20 td.dbg
 */
 body	{background-color: #FEFFFE;}
@@ -48,5 +49,5 @@
 p.nwlink, td.nwlink {font-size: 7pt; text-align: right; margin-top: 0pt;}	/* Link zum Nachweis GB, FS, ..*/
 p.err		{font-size: 11px; color: red;}		/* Fehler -> Anwender */
-p.dbg		{font-size: 10px; color: gray;}		/* Debug -> Entwickler */
+p.dbg, td.dbg{font-size: 10px; color: gray;}		/* Debug -> Entwickler */
 p.cnt		{font-size: 10px; color: gray;}		/* Counter, Zaehler */
 p.warn		{color: gray; font-style: italic;}	/* Warnung, Hinweis */
Index: trunk/info/info/alkisn/alkisexport.php
===================================================================
--- trunk/info/info/alkisn/alkisexport.php	(revision 394)
+++ trunk/info/info/alkisn/alkisexport.php	(revision 398)
@@ -18,5 +18,6 @@
 		?gkz=270&gmlid=2662
 
-	Version
+	Version:
+	--------
 	2016-02-23	Version fuer norGIS-ALKIS-Import
 	2016-10-18	Export einer ganzen Gemarkung zulassen (Sonderfall bei den Parametern)
@@ -24,12 +25,10 @@
 	2017-02-23	Filter mit/ohne Hausnummer zum Typ "strasse".
 				Dazu muss der View "exp_csv_str" um die spalte "fall" erweitert werden.
-				Siehe Datei "x_classic2norgis.sql" in /OSGeo4W64/apps/alkis-import/postcreate.d/
-				Sonderfall: Auch Export zu *allen* StraÃen der Stadt ohne Filter "gmlid".
 	2017-06-08 Validierung Eingabeparameter
 	2017-10-11 Sauber filtern auf endet IS NULL
-
-ToDo:
-	- Geburtsdatum im deutschen Format DD.MM.YYYY ?
-	- In Dateiname StraÃenname statt gmlid verwenden?
+	2017-12-20 Nur eine Adresse zur Person (Siehe Views in "views_exp_csv.sql")
+
+	ToDo:
+	- In Dateiname den StraÃennamen statt der gmlid verwenden? (Umlaute?)
 	- in alkislage.php fÃŒr den Typ "ohne Haunummer" den Export mit strasse und haus=o verlinken
 */
@@ -266,6 +265,8 @@
 	if ($vnam != "") {$name.=", ".$vnam;} // Vorname nach hinten
 	$gebdat=$row["geburtsdatum"];
-
-	// Adresse der Person (Eigentuemer))
+	// Koennte man im View in deutsches Format umwandeln: "to_char(cast(geburtsdatum AS date),'DD.MM.YYYY') AS geburtsdatum"
+
+	// Adresse der Person (Eigentuemer)
+	// Im View ist per subquery geregelt, dass nur die "juengste" Adresse verwendet wird.
 	$ort=$row["ort"];
 	if ($ort == "") {
Index: trunk/info/info/alkisn/alkisnamstruk.php
===================================================================
--- trunk/info/info/alkisn/alkisnamstruk.php	(revision 394)
+++ trunk/info/info/alkisn/alkisnamstruk.php	(revision 398)
@@ -11,4 +11,5 @@
 	2017-10-09 Sauber filtern auf endet IS NULL
 	2017-10-17 Deutsches Datumsformat im Geburtsdatum
+	2017-12-20 Anlass und Datum zur Adresse ausgeben, wenn es mehrere gibt oder SchlÃŒssel angefordert werden
 */
 session_start();
@@ -87,9 +88,13 @@
 
 	// A d r e s s e
-	echo "\n\n<h3><img src='ico/Strasse_mit_Haus.png' width='16' height='16' alt=''> Adresse</h3>";
-	// Es kÃ¶nnen redundante Adressen vorhanden sein, z.B. aus Migration, temporÃ€r aus LBESAS. Die letzte davon anzeigen.
-
-	$sqla ="SELECT a.gml_id, a.ort_post, a.postleitzahlpostzustellung AS plz, a.strasse, a.hausnummer, a.bestimmungsland 
-	FROM ax_anschrift a JOIN ax_person p ON a.gml_id=ANY(p.hat) WHERE p.gml_id= $1 AND a.endet IS NULL AND p.endet IS NULL ORDER BY a.gml_id DESC ;";
+	if ($multiadress == "j") {$plural="n";} else {$plural="";}
+	echo "\n\n<h3><img src='ico/Strasse_mit_Haus.png' width='16' height='16' alt=''> Adresse".$plural."</h3>";
+	// Es kÃ¶nnen redundante Adressen vorhanden sein, z.B. aus Migration, temporÃ€r aus LBESAS.
+	// Im Normalfall nur die "letzte" davon anzeigen. Auf Wunsch alle anzigen, dazu den Anlass und das Datum.
+
+	$sqla ="SELECT a.gml_id, w.v AS anltxt, a.anlass, to_char(cast(a.beginnt AS date),'DD.MM.YYYY') AS datum, a.ort_post, a.postleitzahlpostzustellung AS plz, a.strasse, a.hausnummer, a.bestimmungsland "
+	."FROM ax_anschrift a JOIN ax_person p ON a.gml_id=ANY(p.hat) "
+	."LEFT JOIN alkis_wertearten w ON w.k = ANY(a.anlass) AND element='ax_benutzergruppemitzugriffskontrolle' AND w.bezeichnung='zugriffsartfortfuehrungsanlass' "
+	."WHERE p.gml_id= $1 AND a.endet IS NULL AND p.endet IS NULL ORDER BY a.beginnt DESC ;";
 
 	$v = array($gmlid);
@@ -112,6 +117,18 @@
 			$hsnr=$rowa["hausnummer"];
 			$land=htmlentities($rowa["bestimmungsland"], ENT_QUOTES, "UTF-8");
-			echo "<table>\n"
-				."\t<tr><td class='nhd'>PLZ:</td><td class='nam'>".$plz."</td></tr>\n"
+			$anlass=trim($rowa["anlass"], "{}"); // Key
+			$anltxt=$rowa["anltxt"]; // Value
+			$datum=$rowa["datum"];
+			echo "<table>\n";
+				if ($multiadress == "j" OR $showkey) {
+					if ($debug > 0) { // nur Entw.: Sortierung gml_id vs. beginnt?
+						echo "\t<tr><td class='dbg'>gml_id:</td><td class='dbg'>".$rowa["gml_id"]."</td></tr>\n";
+ 					}
+					echo "\t<tr><td class='nhd'>Datum:</td><td class='nam'>".$datum."</td></tr>\n"
+					."\t<tr><td class='nhd'>Anlass:</td><td class='nam'>";
+					if ($showkey) {echo "<span class='key'>".$anlass."</span> ";}
+					echo $anltxt."</td></tr>\n";
+				}
+				echo "\t<tr><td class='nhd'>PLZ:</td><td class='nam'>".$plz."</td></tr>\n"
 				."\t<tr><td class='nhd'>Ort:</td><td class='nam'>".$ort."</td></tr>\n"
 				."\t<tr><td class='nhd'>Strasse:</td><td class='nam'>".$str."</td></tr>\n"
Index: trunk/info/info/alkisn/alkisfkt.php
===================================================================
--- trunk/info/info/alkisn/alkisfkt.php	(revision 394)
+++ trunk/info/info/alkisn/alkisfkt.php	(revision 398)
@@ -13,4 +13,5 @@
 	2017-10-17 Deutsches Datumsformat fÃŒr Geburtsdatum der Person
 	2017-11-03 neue function werteliste()
+	2017-12-20 Default Anzeigewert "EigentÃŒmer" im Link fÃŒr leere EigentÃŒmerart, JÃŒngste Adresse zur Person verwenden.
 */
 
@@ -438,4 +439,5 @@
 				echo "\n\t\t\t<a href='".$lnkvor."alkisnamstruk.php?gkz=".$gkz."&amp;gmlid=".$rowp[0];
 				if ($showkey) {echo "&amp;showkey=j";}
+				if ($eiartkey == "") {$eiart="Eigent&uuml;mer" ;} // Default. Ersatz-Text, wenn nicht gefÃŒllt
 				echo $lnknach."' title='vollst&auml;ndiger Name und Adresse eines Eigent&uuml;mers'>".$eiart
 				." <img src='ico/Eigentuemer.png' width='16' height='16' alt=''></a>\n\t\t</p>"
@@ -445,5 +447,5 @@
 				// Schleife 3:  A d r e s s e  (OPTIONAL)
 				$sqla ="SELECT a.gml_id, a.ort_post, a.postleitzahlpostzustellung AS plz, a.strasse, a.hausnummer, a.bestimmungsland "
-				."FROM ax_anschrift a JOIN ax_person p ON a.gml_id=ANY(p.hat) WHERE p.gml_id= $1 AND a.endet IS NULL AND p.endet IS NULL LIMIT 2;";
+				."FROM ax_anschrift a JOIN ax_person p ON a.gml_id=ANY(p.hat) WHERE p.gml_id= $1 AND a.endet IS NULL AND p.endet IS NULL ORDER BY a.beginnt DESC LIMIT 2;";
 				$gmlp=$rowp["gml_id"]; // Person
 				$v = array($gmlp);
@@ -458,5 +460,5 @@
 				while($rowa = pg_fetch_array($resa)) {
 					$j++;
-					if ($j == 1) { // erste Adresse anzeigen
+					if ($j == 1) { // erste ("jÃŒngste") Adresse anzeigen
 						$gmla=$rowa["gml_id"];
 						$plz=$rowa["plz"]; // integer
@@ -478,5 +480,5 @@
 						echo "</p></td>\n\t<td>"; // Sp. 3
 						echo "&nbsp;</td>\n</tr>";
-					} else { // manchmal dopplete Angaben (_straÃe / _str.)
+					} else { // manchmal doppelte Angaben
 						echo "\n<tr>\n\t<td>&nbsp;</td>\n\t<td><p class='dbg' title='Siehe Auskunft zur Person'>weitere Adresse</p></td>\n\t<td>&nbsp;</td>\n</tr>";
 					}
